<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr_TR">
<context>
    <name>AuthenticationWidget</name>
    <message>
        <location filename="../src/GUI/authenticationwidget.cpp" line="15"/>
        <source>Username:</source>
        <translation>Kullanıcı adı:</translation>
    </message>
    <message>
        <location filename="../src/GUI/authenticationwidget.cpp" line="16"/>
        <source>Password:</source>
        <translation>Parola:</translation>
    </message>
</context>
<context>
    <name>CadenceGraph</name>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="11"/>
        <source>rpm</source>
        <translation>rpm</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="12"/>
        <location filename="../src/GUI/cadencegraph.h" line="16"/>
        <source>Cadence</source>
        <translation>Kadans</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Ortalama</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="30"/>
        <source>Max</source>
        <translation>En yüksek</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Ortalama</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Azami</translation>
    </message>
</context>
<context>
    <name>CadenceGraphItem</name>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="17"/>
        <source>Maximum</source>
        <translation>Azami</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="18"/>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="20"/>
        <source>rpm</source>
        <translation>rpm</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="19"/>
        <source>Average</source>
        <translation>Ortalama</translation>
    </message>
</context>
<context>
    <name>Data</name>
    <message>
        <location filename="../src/data/data.cpp" line="160"/>
        <source>Supported files</source>
        <translation>Desteklenen dosyalar</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="161"/>
        <source>CSV files</source>
        <translation>CSV dosyaları</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="162"/>
        <source>CUP files</source>
        <translation>CUP dosyaları</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="163"/>
        <source>FIT files</source>
        <translation>FIT dosyaları</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="164"/>
        <source>GeoJSON files</source>
        <translation>GeoJSON dosyaları</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="165"/>
        <source>GPI files</source>
        <translation>GPI dosyaları</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="166"/>
        <source>GPX files</source>
        <translation>GPX dosyaları</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="167"/>
        <source>IGC files</source>
        <translation>IGC dosyaları</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="168"/>
        <source>ITN files</source>
        <translation>ITN dosyaları</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="169"/>
        <source>JPEG images</source>
        <translation>JPEG görüntüleri</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="170"/>
        <source>KML files</source>
        <translation>KML dosyaları</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="171"/>
        <source>LOC files</source>
        <translation>LOC dosyaları</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="172"/>
        <source>NMEA files</source>
        <translation>NMEA dosyaları</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="173"/>
        <source>ONmove files</source>
        <translation>ONmove dosyaları</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="174"/>
        <source>OV2 files</source>
        <translation>OV2 dostaları</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="175"/>
        <source>OziExplorer files</source>
        <translation>OziExplorer dosyaları</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="176"/>
        <source>SLF files</source>
        <translation>SLF dosyaları</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="177"/>
        <source>SML files</source>
        <translation>SML dosyaları</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="178"/>
        <source>TCX files</source>
        <translation>TCX dosyaları</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="179"/>
        <source>TwoNav files</source>
        <translation>TwoNav dosyaları</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="180"/>
        <source>GPSDump files</source>
        <translation>GPSDump dosyaları</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="181"/>
        <source>All files</source>
        <translation>Tüm dosyalar</translation>
    </message>
</context>
<context>
    <name>DirSelectWidget</name>
    <message>
        <location filename="../src/GUI/dirselectwidget.cpp" line="18"/>
        <source>System default</source>
        <translation>Sistem öntanımlı değeri</translation>
    </message>
    <message>
        <location filename="../src/GUI/dirselectwidget.cpp" line="40"/>
        <source>Select directory</source>
        <translation>Dizin seç</translation>
    </message>
</context>
<context>
    <name>ElevationGraph</name>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="39"/>
        <location filename="../src/GUI/elevationgraph.h" line="16"/>
        <source>Elevation</source>
        <translation>Rakım</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="59"/>
        <source>Up</source>
        <extracomment>Use an Unicode arrow (U+2197) when there is no abbreviation or extremly short term for &quot;Up&quot; in your language</extracomment>
        <translation>Yukarı</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="63"/>
        <source>Down</source>
        <extracomment>Use an Unicode arrow (U+2198) when there is no abbreviation or extremly short term for &quot;Down&quot; in your language</extracomment>
        <translation>Aşağı</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="66"/>
        <source>Max</source>
        <extracomment>Use an abbreviation or a extremly short term</extracomment>
        <translation>En yüksek</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="69"/>
        <source>Min</source>
        <extracomment>Use an abbreviation or a extremly short term</extracomment>
        <translation>En düşük</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="72"/>
        <source>Ascent</source>
        <translation>Tırmanış</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="74"/>
        <source>Descent</source>
        <translation>İniş</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="76"/>
        <source>Maximum</source>
        <translation>Azami</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="78"/>
        <source>Minimum</source>
        <translation>Asgari</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="181"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="184"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
</context>
<context>
    <name>ElevationGraphItem</name>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="33"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="33"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="36"/>
        <source>Ascent</source>
        <translation>Tırmanış</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="38"/>
        <source>Descent</source>
        <translation>İniş</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="40"/>
        <source>Maximum</source>
        <translation>Azami</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="42"/>
        <source>Minimum</source>
        <translation>Asgari</translation>
    </message>
</context>
<context>
    <name>FileSelectWidget</name>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="46"/>
        <location filename="../src/GUI/fileselectwidget.cpp" line="51"/>
        <source>Select file</source>
        <translation>Dosya seç</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="61"/>
        <source>No output file selected.</source>
        <translation>Çıktı dosyası seçilmedi.</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="71"/>
        <source>%1 is a directory.</source>
        <translation>%1 bir dizin.</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="75"/>
        <source>%1 is not writable.</source>
        <translation>%1 yazılabilir değil.</translation>
    </message>
</context>
<context>
    <name>Format</name>
    <message>
        <location filename="../src/GUI/format.cpp" line="54"/>
        <location filename="../src/GUI/format.cpp" line="61"/>
        <location filename="../src/GUI/format.cpp" line="84"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="57"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="64"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="68"/>
        <location filename="../src/GUI/format.cpp" line="81"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="71"/>
        <source>km</source>
        <translation>km</translation>
    </message>
</context>
<context>
    <name>GUI</name>
    <message>
        <location filename="../src/GUI/gui.cpp" line="199"/>
        <source>Quit</source>
        <translation>Çıkış</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="207"/>
        <location filename="../src/GUI/gui.cpp" line="951"/>
        <location filename="../src/GUI/gui.cpp" line="969"/>
        <source>Paths</source>
        <translation>Klasör konumları</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="211"/>
        <location filename="../src/GUI/gui.cpp" line="911"/>
        <location filename="../src/GUI/gui.cpp" line="912"/>
        <source>Keyboard controls</source>
        <translation>Klavye denetimleri</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="215"/>
        <location filename="../src/GUI/gui.cpp" line="878"/>
        <source>About GPXSee</source>
        <translation>GPXSee hakkında</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="221"/>
        <source>Open...</source>
        <translation>Aç...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="228"/>
        <source>Open directory...</source>
        <translation>Dizin aç...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="233"/>
        <source>Print...</source>
        <translation>Yazdır...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="239"/>
        <source>Export to PDF...</source>
        <translation>PDF olarak dışa aktar...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="246"/>
        <source>Export to PNG...</source>
        <translation>PNG olarak dışa aktar...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="253"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="260"/>
        <source>Reload</source>
        <translation>Yeniden yükle</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="266"/>
        <source>Statistics...</source>
        <translation>İstatistikler...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="276"/>
        <source>Clear list</source>
        <translation>Listeyi temizle</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="288"/>
        <source>Load POI file...</source>
        <translation>POI dosyası yükle...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="292"/>
        <source>Select all files</source>
        <translation>Tüm dosyaları seç</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="297"/>
        <source>Unselect all files</source>
        <translation>Tüm dosyaların seçimini kaldır</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="302"/>
        <source>Overlap POIs</source>
        <translation>POI&apos;leri üst üste getir</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="307"/>
        <source>Show POI icons</source>
        <translation>POI simgelerini göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="312"/>
        <source>Show POI labels</source>
        <translation>POI etiketlerini göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="318"/>
        <source>Show POIs</source>
        <translation>POI&apos;leri göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="330"/>
        <source>Show map</source>
        <translation>Haritayı göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="339"/>
        <source>Load map...</source>
        <translation>Harita yükle...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="344"/>
        <source>Load map directory...</source>
        <translation>Harita dizinini yükle...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="347"/>
        <source>Clear tile cache</source>
        <translation>Döşeme önbelleğini temizle</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="352"/>
        <location filename="../src/GUI/gui.cpp" line="357"/>
        <location filename="../src/GUI/gui.cpp" line="930"/>
        <source>Next map</source>
        <translation>Sonraki harita</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="362"/>
        <source>Show cursor coordinates</source>
        <translation>İmleç koordinatlarını göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="370"/>
        <source>Show position</source>
        <translation>Konumu göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="376"/>
        <source>Follow position</source>
        <translation>Konumu takip et</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="381"/>
        <source>Show coordinates</source>
        <translation>Koordinatları göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="387"/>
        <source>Show motion info</source>
        <translation>Hareket bilgilerini göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="394"/>
        <source>Show tracks</source>
        <translation>İzleri göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="399"/>
        <source>Show routes</source>
        <translation>Rotaları göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="403"/>
        <source>Show waypoints</source>
        <translation>Yer işaretlerini göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="408"/>
        <source>Show areas</source>
        <translation>Alanları göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="412"/>
        <source>Waypoint icons</source>
        <translation>Ara nokta simgeleri</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="417"/>
        <source>Waypoint labels</source>
        <translation>Yer işareti etiketleri</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="422"/>
        <source>Route waypoints</source>
        <translation>Rota yer işaretleri</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="427"/>
        <source>km/mi markers</source>
        <translation>km/mil işaretleri</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="435"/>
        <source>Do not show</source>
        <translation>Gösterme</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="439"/>
        <source>Marker only</source>
        <translation>Yalnızca işaretleyici</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="443"/>
        <source>Date/time</source>
        <translation>Tarih/saat</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="447"/>
        <source>Coordinates</source>
        <translation>Koordinatlar</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="451"/>
        <source>Use styles</source>
        <translation>Tarzları kullan</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="469"/>
        <source>Show local DEM tiles</source>
        <translation>Yerel DEM döşemelerini göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="472"/>
        <source>Show hillshading</source>
        <translation>Tepe gölgelendirmesini göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="480"/>
        <source>Show graphs</source>
        <translation>Grafikleri göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="488"/>
        <location filename="../src/GUI/gui.cpp" line="1370"/>
        <location filename="../src/GUI/gui.cpp" line="1430"/>
        <source>Distance</source>
        <translation>Mesafe</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="495"/>
        <location filename="../src/GUI/gui.cpp" line="740"/>
        <location filename="../src/GUI/gui.cpp" line="1372"/>
        <location filename="../src/GUI/gui.cpp" line="1432"/>
        <source>Time</source>
        <translation>Zaman</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="501"/>
        <source>Show grid</source>
        <translation>Izgarayı göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="506"/>
        <source>Show slider info</source>
        <translation>Kaydırıcı bilgisi göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="512"/>
        <source>Show tabs</source>
        <translation>Sekmeleri göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="521"/>
        <source>Show toolbars</source>
        <translation>Araç çubuklarını göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="528"/>
        <source>Total time</source>
        <translation>Toplam süre</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="533"/>
        <location filename="../src/GUI/gui.cpp" line="1373"/>
        <location filename="../src/GUI/gui.cpp" line="1434"/>
        <source>Moving time</source>
        <translation>Hareket süresi</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="540"/>
        <source>Metric</source>
        <translation>Metrik</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="545"/>
        <source>Imperial</source>
        <translation>İngiliz</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="551"/>
        <source>Nautical</source>
        <translation>Denizcilik</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="559"/>
        <source>Decimal degrees (DD)</source>
        <translation>Desimal derece (DD)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="565"/>
        <source>Degrees and decimal minutes (DMM)</source>
        <translation>Derece ve desimal dakika (DDD)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="572"/>
        <source>Degrees, minutes, seconds (DMS)</source>
        <translation>Derece, dakika, saniye (DDS)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="579"/>
        <source>Fullscreen mode</source>
        <translation>Tam ekran modu</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="586"/>
        <source>Options...</source>
        <translation>Seçenekler...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="593"/>
        <source>Next</source>
        <translation>Sonraki</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="598"/>
        <source>Previous</source>
        <translation>Önceki</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="603"/>
        <source>Last</source>
        <translation>Son</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="608"/>
        <source>First</source>
        <translation>İlk</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="643"/>
        <source>&amp;File</source>
        <translation>&amp;Dosya</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="646"/>
        <source>Open recent</source>
        <translation>Son kullanılanları aç</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="671"/>
        <source>&amp;Map</source>
        <translation>&amp;Harita</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="681"/>
        <source>&amp;Graph</source>
        <translation>&amp;Grafik</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="712"/>
        <source>&amp;POI</source>
        <translation>&amp;POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="732"/>
        <source>Position</source>
        <translation>Konum</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="958"/>
        <location filename="../src/GUI/gui.cpp" line="976"/>
        <source>CRS directory:</source>
        <translation>CRS dizini:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="964"/>
        <location filename="../src/GUI/gui.cpp" line="982"/>
        <source>Symbols directory:</source>
        <translation>Semboller dizini:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1030"/>
        <source>Open directory</source>
        <translation>Dizin aç</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1101"/>
        <location filename="../src/GUI/gui.cpp" line="1778"/>
        <location filename="../src/GUI/gui.cpp" line="1878"/>
        <source>Don&apos;t show again</source>
        <translation>Tekrar gösterme</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1941"/>
        <source>Clear &quot;%1&quot; tile cache?</source>
        <translation>&quot;%1&quot; döşeme önbelleği temizlensin mi?</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/GUI/gui.cpp" line="1964"/>
        <source>Download %n DEM tiles?</source>
        <translation>
            <numerusform>%n DEM döşemesi indirilsin mi?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="693"/>
        <source>&amp;Data</source>
        <translation>&amp;Veri</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="458"/>
        <source>Download data DEM</source>
        <translation>DEM verisini indir</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="464"/>
        <source>Download map DEM</source>
        <translation>DEM haritasını indir</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="698"/>
        <source>Position info</source>
        <translation>Konum bilgisi</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="724"/>
        <source>DEM</source>
        <translation>DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="739"/>
        <source>&amp;Settings</source>
        <translation>&amp;Ayarlar</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="744"/>
        <source>Units</source>
        <translation>Birimler</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="749"/>
        <source>Coordinates format</source>
        <translation>Koordinat biçimi</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="762"/>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="789"/>
        <source>File</source>
        <translation>Dosya</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="799"/>
        <source>Show</source>
        <translation>Göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="807"/>
        <source>Navigation</source>
        <translation>Navigasyon</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="880"/>
        <location filename="../src/GUI/gui.cpp" line="888"/>
        <source>Version %1</source>
        <translation>Sürüm %1</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="883"/>
        <location filename="../src/GUI/gui.cpp" line="892"/>
        <source>GPXSee is distributed under the terms of the GNU General Public License version 3. For more info about GPXSee visit the project homepage at %1.</source>
        <translation>GPXSee, GNU Genel Kamu Lisansı sürüm 3 şartlarına göre dağıtılır. GPXSee hakkında daha fazla bilgi için %1 proje ana sayfasını ziyaret edin.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="915"/>
        <source>Next file</source>
        <translation>Sonraki dosya</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="916"/>
        <source>Previous file</source>
        <translation>Önceki dosya</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="918"/>
        <source>First file</source>
        <translation>İlk dosya</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="920"/>
        <source>Last file</source>
        <translation>Son dosya</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="921"/>
        <source>Append file</source>
        <translation>Dosya ekle</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="922"/>
        <source>Next/Previous</source>
        <translation>Sonraki/Önceki</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="924"/>
        <source>Toggle graph type</source>
        <translation>Geçiş grafik türü</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="926"/>
        <source>Toggle time type</source>
        <translation>Geçiş zaman türü</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="928"/>
        <source>Toggle position info</source>
        <translation>Konum bilgilerini değiştir</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="932"/>
        <source>Previous map</source>
        <translation>Önceki harita</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="933"/>
        <source>Zoom in</source>
        <translation>Yaklaş</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="935"/>
        <source>Zoom out</source>
        <translation>Uzaklaş</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="937"/>
        <source>Digital zoom</source>
        <translation>Dijital yakınlaştırma</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="938"/>
        <source>Zoom</source>
        <translation>Yakınlaştırma</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="939"/>
        <source>Copy coordinates</source>
        <translation>Koordinatları kopyala</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="940"/>
        <source>Left Click</source>
        <translation>Sol Tık</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="954"/>
        <location filename="../src/GUI/gui.cpp" line="972"/>
        <source>Map directory:</source>
        <translation>Harita dizini:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="956"/>
        <location filename="../src/GUI/gui.cpp" line="974"/>
        <source>POI directory:</source>
        <translation>POI dizini:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="960"/>
        <location filename="../src/GUI/gui.cpp" line="978"/>
        <source>DEM directory:</source>
        <translation>DEM dizini:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="962"/>
        <location filename="../src/GUI/gui.cpp" line="980"/>
        <source>Styles directory:</source>
        <translation>Tarz dizini:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="966"/>
        <location filename="../src/GUI/gui.cpp" line="984"/>
        <source>Tile cache directory:</source>
        <translation>Döşeme önbellek dizini:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="995"/>
        <location filename="../src/GUI/gui.cpp" line="998"/>
        <source>Open file</source>
        <translation>Dosya aç</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1093"/>
        <source>Error loading data file:</source>
        <translation>Veri dosyası yüklenirken hata oluştu:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1096"/>
        <location filename="../src/GUI/gui.cpp" line="1208"/>
        <source>Line: %1</source>
        <translation>Satır: %1</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1175"/>
        <location filename="../src/GUI/gui.cpp" line="1178"/>
        <source>Open POI file</source>
        <translation>POI dosyası aç</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1205"/>
        <source>Error loading POI file:</source>
        <translation>POI dosyası yükleme hatası:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1352"/>
        <location filename="../src/GUI/gui.cpp" line="1410"/>
        <source>Tracks</source>
        <translation>İzler</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1354"/>
        <location filename="../src/GUI/gui.cpp" line="1412"/>
        <source>Routes</source>
        <translation>Rotalar</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1356"/>
        <location filename="../src/GUI/gui.cpp" line="1414"/>
        <source>Waypoints</source>
        <translation>Yer işaretleri</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1358"/>
        <location filename="../src/GUI/gui.cpp" line="1416"/>
        <source>Areas</source>
        <translation>Alanlar</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1362"/>
        <location filename="../src/GUI/gui.cpp" line="1364"/>
        <location filename="../src/GUI/gui.cpp" line="1421"/>
        <location filename="../src/GUI/gui.cpp" line="1423"/>
        <source>Date</source>
        <translation>Tarih</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1385"/>
        <location filename="../src/GUI/gui.cpp" line="1388"/>
        <location filename="../src/GUI/gui.cpp" line="1389"/>
        <source>Statistics</source>
        <translation>İstatistikler</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1406"/>
        <source>Name</source>
        <translation>Adı</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1717"/>
        <location filename="../src/GUI/gui.cpp" line="1720"/>
        <source>Open map file</source>
        <translation>Harita dosyası aç</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1772"/>
        <location filename="../src/GUI/gui.cpp" line="1829"/>
        <location filename="../src/GUI/gui.cpp" line="1848"/>
        <location filename="../src/GUI/gui.cpp" line="1872"/>
        <source>Error loading map:</source>
        <translation>Harita yüklenirken hata oluştu:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1912"/>
        <source>Select map directory</source>
        <translation>Harita dizinini seç</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1961"/>
        <source>DEM tiles download limit exceeded. If you really need data for such a huge area, download the files manually.</source>
        <translation>DEM döşemeleri indirme sınırı aşıldı. Bu kadar büyük bir alan için gerçekten veriye ihtiyacınız varsa, dosyaları elle indirin.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1977"/>
        <source>Could not download all required DEM files.</source>
        <translation>Gerekli tüm DEM dosyaları indirilemedi.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1997"/>
        <source>No local DEM tiles found.</source>
        <translation>Yerel DEM döşemesi bulunamadı.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2011"/>
        <source>No files loaded</source>
        <translation>Hiç dosya yüklenmedi</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/GUI/gui.cpp" line="2015"/>
        <source>%n files</source>
        <translation>
            <numerusform>%n dosya</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GearRatioGraph</name>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="12"/>
        <location filename="../src/GUI/gearratiograph.h" line="17"/>
        <source>Gear ratio</source>
        <translation>Dişli oranı</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="28"/>
        <source>Top</source>
        <translation>Üst</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="30"/>
        <source>Min</source>
        <translation>En düşük</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="32"/>
        <source>Max</source>
        <translation>En yüksek</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="35"/>
        <source>Most used</source>
        <translation>Sık kullanılan</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Asgari</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="39"/>
        <source>Maximum</source>
        <translation>Azami</translation>
    </message>
</context>
<context>
    <name>GearRatioGraphItem</name>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="35"/>
        <source>Minimum</source>
        <translation>Asgari</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="36"/>
        <source>Maximum</source>
        <translation>Azami</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="37"/>
        <source>Most used</source>
        <translation>Sık kullanılan</translation>
    </message>
</context>
<context>
    <name>GraphView</name>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="74"/>
        <source>Data not available</source>
        <translation>Veri yok</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="94"/>
        <location filename="../src/GUI/graphview.cpp" line="199"/>
        <source>Distance</source>
        <translation>Mesafe</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="131"/>
        <location filename="../src/GUI/graphview.cpp" line="139"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="134"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="142"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="147"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="150"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="156"/>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="159"/>
        <source>min</source>
        <translation>dak</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="162"/>
        <source>h</source>
        <translation>sa</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="201"/>
        <source>Time</source>
        <translation>Zaman</translation>
    </message>
</context>
<context>
    <name>HeartRateGraph</name>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="11"/>
        <source>bpm</source>
        <translation>bpm</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="12"/>
        <location filename="../src/GUI/heartrategraph.h" line="16"/>
        <source>Heart rate</source>
        <translation>Nabız</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Ortalama</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="30"/>
        <source>Max</source>
        <translation>En yüksek</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Ortalama</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Azami</translation>
    </message>
</context>
<context>
    <name>HeartRateGraphItem</name>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="17"/>
        <source>Maximum</source>
        <translation>Azami</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="18"/>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="20"/>
        <source>bpm</source>
        <translation>bpm</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="19"/>
        <source>Average</source>
        <translation>Ortalama</translation>
    </message>
</context>
<context>
    <name>MapItem</name>
    <message>
        <location filename="../src/GUI/mapitem.cpp" line="79"/>
        <source>Name</source>
        <translation>Ad</translation>
    </message>
    <message>
        <location filename="../src/GUI/mapitem.cpp" line="81"/>
        <source>File</source>
        <translation>Dosya</translation>
    </message>
</context>
<context>
    <name>MapList</name>
    <message>
        <location filename="../src/map/maplist.cpp" line="158"/>
        <source>Supported files</source>
        <translation>Desteklenen dosyalar</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="171"/>
        <source>MBTiles maps</source>
        <translation>MBTiles haritaları</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="166"/>
        <source>Garmin JNX maps</source>
        <translation>Garmin JNX haritaları</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="162"/>
        <source>AlpineQuest maps</source>
        <translation>AlpineQuest haritaları</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="164"/>
        <source>Garmin IMG maps</source>
        <translation>Garmin IMG haritaları</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="167"/>
        <source>BSB nautical charts</source>
        <translation>BSB denizcilik haritaları</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="163"/>
        <source>GEMF maps</source>
        <translation>GEMF haritaları</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="160"/>
        <source>Electronic Navigational Charts</source>
        <translation>Elektronik Seyir Haritaları</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="168"/>
        <source>KMZ maps</source>
        <translation>KMZ haritaları</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="169"/>
        <source>Mapsforge maps</source>
        <translation>Mapsforge haritaları</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="170"/>
        <source>OziExplorer maps</source>
        <translation>OziExplorer haritaları</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="172"/>
        <source>Orux maps</source>
        <translation>Orux haritaları</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="173"/>
        <source>QuickChart maps</source>
        <translation>QuickChart haritaları</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="175"/>
        <source>Osmdroid SQLite maps</source>
        <translation>Osmdroid SQLite haritaları</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="178"/>
        <source>TrekBuddy maps/atlases</source>
        <translation>TrekBuddy haritaları/atlasları</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="180"/>
        <source>GeoTIFF images</source>
        <translation>GeoTIFF görüntüleri</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="184"/>
        <source>All files</source>
        <translation>Tüm dosyalar</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="174"/>
        <source>TwoNav maps</source>
        <translation>TwoNav haritaları</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="176"/>
        <source>Locus/OsmAnd/RMaps SQLite maps</source>
        <translation>Locus/OsmAnd/RMaps SQLite haritaları</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="181"/>
        <source>World-file georeferenced images</source>
        <translation>World-file coğrafi referanslı görüntüleri</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="183"/>
        <source>Online map sources</source>
        <translation>Çevrim içi harita kaynakları</translation>
    </message>
</context>
<context>
    <name>MotionInfoItem</name>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="87"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="90"/>
        <source>mi/h</source>
        <translation>mi/sa</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="93"/>
        <source>km/h</source>
        <translation>km/sa</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="100"/>
        <source>ft/min</source>
        <translation>ft/dak</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="103"/>
        <source>m/min</source>
        <translation>m/dak</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="78"/>
        <source>Standard</source>
        <translation>Standart</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="83"/>
        <source>Non-HiDPI maps are loaded as HiDPI maps. The map is sharp but map objects are small/hard to read.</source>
        <translation>HiDPI olmayan haritalar, HiDPI haritaları olarak yüklenir. Harita keskin ama harita nesneleri küçük/okunması zor.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="85"/>
        <source>Non-HiDPI maps are loaded such as they are. Map objects have the expected size but the map is blurry.</source>
        <translation>HiDPI olmayan haritalar, oldukları gibi yüklenir. Harita nesneleri beklenen boyuta sahip ancak harita bulanıktır.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="129"/>
        <source>HiDPI display mode</source>
        <translation>HiDPI gösterim modu</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="179"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="202"/>
        <source>Base color:</source>
        <translation>Temel renk:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="180"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="203"/>
        <source>Palette shift:</source>
        <translation>Palet değişimi:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="169"/>
        <source>Track width:</source>
        <translation>İz genişliği:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="95"/>
        <source>Input</source>
        <translation>Girdi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="97"/>
        <source>Output</source>
        <translation>Çıktı</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="170"/>
        <source>Track style:</source>
        <translation>İz tarzı:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="186"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="191"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="196"/>
        <source>Width:</source>
        <translation>Genişlik:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="187"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="192"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="197"/>
        <source>Style:</source>
        <translation>Tarz:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="188"/>
        <source>Tracks</source>
        <translation>İzler</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="172"/>
        <source>Route width:</source>
        <translation>Rota genişliği:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="173"/>
        <source>Route style:</source>
        <translation>Rota tarzı:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="193"/>
        <source>Routes</source>
        <translation>Rotalar</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="175"/>
        <source>Area border width:</source>
        <translation>Alan sınır genişliği:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="176"/>
        <source>Area border style:</source>
        <translation>Alan sınır tarzı:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="177"/>
        <source>Area fill opacity:</source>
        <translation>Alan dolgusu opaklığı:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="199"/>
        <source>Areas</source>
        <translation>Alanlar</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="163"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="267"/>
        <source>Use anti-aliasing</source>
        <translation>Kenar yumuşatma kullan</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="235"/>
        <source>Waypoint color:</source>
        <translation>Yer işareti rengi:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="236"/>
        <source>Waypoint size:</source>
        <translation>Yer işareti boyutu:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="243"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="248"/>
        <source>Color:</source>
        <translation>Renk:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="244"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="249"/>
        <source>Size:</source>
        <translation>Boyut:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="245"/>
        <source>Waypoints</source>
        <translation>Yer işaretleri</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="238"/>
        <source>POI color:</source>
        <translation>POI renk:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="239"/>
        <source>POI size:</source>
        <translation>POI boyutu:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="250"/>
        <source>POIs</source>
        <translation>POI&apos;ler</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="273"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="279"/>
        <source>Line width:</source>
        <translation>Hat genişliği:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="274"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="280"/>
        <source>Slider color:</source>
        <translation>Kaydırıcı rengi:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="305"/>
        <source>Background color:</source>
        <translation>Arka plan rengi:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="318"/>
        <source>Paths</source>
        <translation>Klasör konumları</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="319"/>
        <source>Points</source>
        <translation>Noktalar</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="320"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="757"/>
        <source>Graphs</source>
        <translation>Grafikler</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="321"/>
        <source>Map</source>
        <translation>Harita</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="328"/>
        <source>Moving average window size</source>
        <translation>Ortalama pencere boyutuna taşıma</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="353"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="363"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="480"/>
        <source>Elevation:</source>
        <translation>Rakım:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="354"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="364"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="479"/>
        <source>Speed:</source>
        <translation>Hız:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="355"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="365"/>
        <source>Heart rate:</source>
        <translation>Nabız:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="356"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="366"/>
        <source>Cadence:</source>
        <translation>Kadans:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="357"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="367"/>
        <source>Power:</source>
        <translation>Güç:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="352"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="370"/>
        <source>Smoothing</source>
        <translation>Yumuşatma</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="346"/>
        <source>Eliminate GPS outliers</source>
        <translation>Aykırı GPS ele</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="380"/>
        <source>Automatic</source>
        <translation>Otomatik</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="394"/>
        <source>mi/h</source>
        <translation>mi/sa</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="397"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="400"/>
        <source>km/h</source>
        <translation>km/sa</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="404"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="784"/>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="527"/>
        <source>Minimal speed:</source>
        <translation>Asgari hız:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="528"/>
        <source>Minimal duration:</source>
        <translation>Asgari süre:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="411"/>
        <source>Computed from distance/time</source>
        <translation>Mesafe/zamandan hesaplandı</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="412"/>
        <source>Recorded by device</source>
        <translation>Aygıttan kaydedilen</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="417"/>
        <source>Show secondary speed</source>
        <translation>İkincil hızı göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="420"/>
        <source>GPS data</source>
        <translation>GPS verisi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="421"/>
        <source>DEM data</source>
        <translation>DEM verileri</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="426"/>
        <source>Show secondary elevation</source>
        <translation>İkincil rakımı göster</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="429"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="450"/>
        <source>Use segments</source>
        <translation>Bölümleri kullan</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="481"/>
        <source>Time zone:</source>
        <translation>Saat dilimi:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="500"/>
        <source>Elevation</source>
        <translation>Rakım</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="506"/>
        <source>Time zone</source>
        <translation>Saat dilimi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="540"/>
        <source>Filtering</source>
        <translation>Filtreleme</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="539"/>
        <source>Sources</source>
        <translation>Kaynaklar</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="541"/>
        <source>Pause detection</source>
        <translation>Duraklama algılama</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="563"/>
        <source>Radius:</source>
        <translation>Yarıçap:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="495"/>
        <source>Speed</source>
        <translation>Hız</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="70"/>
        <source>Select the proper coordinate reference system (CRS) of maps without a CRS definition (JNX, KMZ and World file maps).</source>
        <translation>CRS tanımı olmayan haritaların (JNX, KMZ ve Dünya dosya haritaları) uygun koordinat referans sistemini (CRS) seçin.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="73"/>
        <source>Select the desired projection of vector maps (IMG, Mapsforge and ENC maps). The projection must be valid for the whole map area.</source>
        <translation>Vektör haritalarının (IMG, Mapsforge ve ENC haritaları) istenen iz düşümünü seçin. İz düşümü tüm harita alanı için geçerli olmalıdır.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="104"/>
        <source>Input:</source>
        <translation>Girdi:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="107"/>
        <source>Output:</source>
        <translation>Çıktı:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="128"/>
        <source>Projection</source>
        <translation>İz düşümü</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="139"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="146"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="152"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="220"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="227"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="265"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="628"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="301"/>
        <source>Info background</source>
        <translation>Bilgi arka planı</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="307"/>
        <source>Crosshair color:</source>
        <translation>Artı işareti rengi:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="308"/>
        <source>Info color:</source>
        <translation>Bilgi rengi:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="381"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="431"/>
        <source>Custom</source>
        <translation>Özel</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="553"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="556"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="559"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="569"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="877"/>
        <source>POI</source>
        <translation>POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="586"/>
        <source>Use HTTP authentication</source>
        <translation>HTTP kimlik doğrulamasını kullan</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="592"/>
        <source>Use $lat and $lon for NYY/SYY and EXXX/WXXX in the URL.</source>
        <translation>URL&apos;de NYY/SYY ve EXXX/WXXX için $lat ve $lon kullan.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="597"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="610"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="198"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="306"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="644"/>
        <source>Opacity:</source>
        <translation>Matlık:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="646"/>
        <source>Blur radius:</source>
        <translation>Bulanıklık yarıçapı:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="648"/>
        <source>Azimuth:</source>
        <translation>Azimut:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="649"/>
        <source>Altitude:</source>
        <translation>Rakım:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="650"/>
        <source>Z Factor:</source>
        <translation>Z Çarpanı:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="655"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="689"/>
        <source>Source</source>
        <translation>Kaynak</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="656"/>
        <source>Hillshading</source>
        <translation>Tepe gölgelendirmesi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="676"/>
        <source>Plugin:</source>
        <translation>Eklenti:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="696"/>
        <source>WYSIWYG</source>
        <translation>WYSIWYG</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="77"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="697"/>
        <source>High-Resolution</source>
        <translation>Yüksek çözünürlük</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="645"/>
        <source>Lightening:</source>
        <translation>Işıklandırma:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="702"/>
        <source>The printed area is approximately the display area. The map zoom level does not change.</source>
        <translation>Yazdırılan alan yaklaşık olarak görüntü alanıdır. Harita zum seviyesi değişmez.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="704"/>
        <source>The zoom level will be changed so that the whole content (tracks/waypoints) fits to the printed area and the map resolution is as close as possible to the print resolution.</source>
        <translation>Yakınlaştırma seviyesi, tüm içeriğin (izler/yer işaretleri) yazdırılan alana sığması ve harita çözünürlüğünün baskı çözünürlüğüne olabildiğince yakın olacak şekilde değiştirilecektir.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="720"/>
        <source>Name</source>
        <translation>Adı</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="722"/>
        <source>Date</source>
        <translation>Tarih</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="724"/>
        <source>Distance</source>
        <translation>Mesafe</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="726"/>
        <source>Time</source>
        <translation>Zaman</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="728"/>
        <source>Moving time</source>
        <translation>Hareket süresi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="730"/>
        <source>Item count (&gt;1)</source>
        <translation>Öge sayısı (&gt;1)</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="745"/>
        <source>Separate graph page</source>
        <translation>Ayrı grafik sayfası</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="755"/>
        <source>Print mode</source>
        <translation>Yazdırma modu</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="756"/>
        <source>Header</source>
        <translation>Başlık</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="764"/>
        <source>Use OpenGL</source>
        <translation>OpenGL kullan</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="766"/>
        <source>Enable HTTP/2</source>
        <translation>HTTP/2 etkinleştir</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="772"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="778"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="790"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="798"/>
        <source>Image cache size:</source>
        <translation>Görüntü önbellek boyutu:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="792"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="800"/>
        <source>Connection timeout:</source>
        <translation>Bağlantı zaman aşımı:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="430"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="835"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="886"/>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="791"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="799"/>
        <source>DEM cache size:</source>
        <translation>DEM önbellek boyutu:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="819"/>
        <source>Select the initial paths of the file open dialogues. Leave the field empty for the system default.</source>
        <translation>Dosya açma iletişim kutularının ilk yollarını seçin. Sistem öntanımlı değeri için alanı boş bırakın.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="823"/>
        <source>Data:</source>
        <translation>Veri:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="824"/>
        <source>Maps:</source>
        <translation>Haritalar:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="825"/>
        <source>POI:</source>
        <translation>POI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="836"/>
        <source>Initial paths</source>
        <translation>İlk yollar</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="872"/>
        <source>Appearance</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="874"/>
        <source>Maps</source>
        <translation>Haritalar</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="876"/>
        <source>Data</source>
        <translation>Veri</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="879"/>
        <source>DEM</source>
        <translation>DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="882"/>
        <source>Position</source>
        <translation>Konum</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="884"/>
        <source>Print &amp; Export</source>
        <translation>Yazdır &amp; Dışa aktar</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="919"/>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
</context>
<context>
    <name>PDFExportDialog</name>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="28"/>
        <source>PDF files</source>
        <translation>PDF dosyaları</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="28"/>
        <source>All files</source>
        <translation>Tüm dosyalar</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="56"/>
        <source>Portrait</source>
        <translation>Dikey</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="57"/>
        <source>Landscape</source>
        <translation>Yatay</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="67"/>
        <source>in</source>
        <translation>inç</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="67"/>
        <source>cm</source>
        <translation>cm</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="73"/>
        <source>Page Setup</source>
        <translation>Sayfa Düzeni</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="76"/>
        <source>Page size:</source>
        <translation>Sayfa boyutu:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="77"/>
        <source>Resolution:</source>
        <translation>Çözünürlük:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="78"/>
        <source>Orientation:</source>
        <translation>Yönlendirme:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="79"/>
        <source>Margins:</source>
        <translation>Kenar boşlukları:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="85"/>
        <source>File:</source>
        <translation>Dosya:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="92"/>
        <source>Output file</source>
        <translation>Çıktı dosyası</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="99"/>
        <source>Export</source>
        <translation>Dışa aktar</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="119"/>
        <source>Export to PDF</source>
        <translation>PDF olarak dışa aktar</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="127"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
</context>
<context>
    <name>PNGExportDialog</name>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="25"/>
        <source>PNG files</source>
        <translation>PNG dosyaları</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="25"/>
        <source>All files</source>
        <translation>Tüm dosyalar</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="34"/>
        <location filename="../src/GUI/pngexportdialog.cpp" line="39"/>
        <location filename="../src/GUI/pngexportdialog.cpp" line="43"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="45"/>
        <source>Use anti-aliasing</source>
        <translation>Kenar yumuşatma kullan</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="49"/>
        <source>Image Setup</source>
        <translation>Görüntü Düzeni</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="52"/>
        <source>Image width:</source>
        <translation>Görüntü genişliği:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="53"/>
        <source>Image height:</source>
        <translation>Görüntü yüksekliği:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="54"/>
        <source>Margins:</source>
        <translation>Kenar boşlukları:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="61"/>
        <source>File:</source>
        <translation>Dosya:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="68"/>
        <source>Output file</source>
        <translation>Çıktı dosyası</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="75"/>
        <source>Export</source>
        <translation>Dışa aktar</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="95"/>
        <source>Export to PNG</source>
        <translation>PNG olarak dışa aktar</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="103"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
</context>
<context>
    <name>PolygonItem</name>
    <message>
        <location filename="../src/GUI/areaitem.cpp" line="17"/>
        <source>Name</source>
        <translation>Adı</translation>
    </message>
    <message>
        <location filename="../src/GUI/areaitem.cpp" line="19"/>
        <source>Description</source>
        <translation>Açıklama</translation>
    </message>
</context>
<context>
    <name>PowerGraph</name>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="11"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="12"/>
        <location filename="../src/GUI/powergraph.h" line="16"/>
        <source>Power</source>
        <translation>Güç</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Ortalama</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="30"/>
        <source>Max</source>
        <translation>En yüksek</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Ortalama</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Azami</translation>
    </message>
</context>
<context>
    <name>PowerGraphItem</name>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="17"/>
        <source>Maximum</source>
        <translation>Azami</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="18"/>
        <location filename="../src/GUI/powergraphitem.cpp" line="20"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="19"/>
        <source>Average</source>
        <translation>Ortalama</translation>
    </message>
</context>
<context>
    <name>RouteItem</name>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="16"/>
        <source>Name</source>
        <translation>Adı</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="18"/>
        <source>Description</source>
        <translation>Açıklama</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="20"/>
        <source>Comment</source>
        <translation>Yorum</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="21"/>
        <source>Distance</source>
        <translation>Mesafe</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="32"/>
        <source>Links</source>
        <translation>Bağlantılar</translation>
    </message>
</context>
<context>
    <name>ScaleItem</name>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="108"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="109"/>
        <location filename="../src/GUI/scaleitem.cpp" line="112"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="111"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="114"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="115"/>
        <source>m</source>
        <translation>m</translation>
    </message>
</context>
<context>
    <name>SpeedGraph</name>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="15"/>
        <location filename="../src/GUI/speedgraph.h" line="18"/>
        <source>Speed</source>
        <translation>Hız</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="30"/>
        <source>min/km</source>
        <translation>min/km</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="31"/>
        <source>min/mi</source>
        <translation>min/mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="31"/>
        <source>min/nmi</source>
        <translation>min/nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="34"/>
        <source>Avg</source>
        <translation>Ortalama</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="36"/>
        <source>Max</source>
        <translation>En yüksek</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="39"/>
        <source>Average</source>
        <translation>Ortalama</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="41"/>
        <source>Maximum</source>
        <translation>Azami</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="44"/>
        <source>Pace</source>
        <translation>Hız</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="133"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="136"/>
        <source>mi/h</source>
        <translation>mi/sa</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="139"/>
        <source>km/h</source>
        <translation>km/sa</translation>
    </message>
</context>
<context>
    <name>SpeedGraphItem</name>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="23"/>
        <source>mi/h</source>
        <translation>mi/sa</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="24"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="24"/>
        <source>km/h</source>
        <translation>km/sa</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="27"/>
        <source>min/km</source>
        <translation>min/km</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="28"/>
        <source>min/mi</source>
        <translation>min/mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="28"/>
        <source>min/nmi</source>
        <translation>min/nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="31"/>
        <source>Maximum</source>
        <translation>Azami</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="33"/>
        <source>Average</source>
        <translation>Ortalama</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="35"/>
        <source>Pace</source>
        <translation>Hız</translation>
    </message>
</context>
<context>
    <name>TemperatureGraph</name>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="12"/>
        <location filename="../src/GUI/temperaturegraph.h" line="16"/>
        <source>Temperature</source>
        <translation>Sıcaklık</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Ortalama</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="30"/>
        <source>Min</source>
        <translation>En düşük</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="32"/>
        <source>Max</source>
        <translation>En yüksek</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="35"/>
        <source>Average</source>
        <translation>Ortalama</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Asgari</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="39"/>
        <source>Maximum</source>
        <translation>Azami</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="111"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="115"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>TemperatureGraphItem</name>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="21"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="21"/>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="24"/>
        <source>Average</source>
        <translation>Ortalama</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="26"/>
        <source>Maximum</source>
        <translation>Azami</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="28"/>
        <source>Minimum</source>
        <translation>Asgari</translation>
    </message>
</context>
<context>
    <name>TrackItem</name>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="15"/>
        <source>Name</source>
        <translation>Adı</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="17"/>
        <source>Description</source>
        <translation>Açıklama</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="19"/>
        <source>Comment</source>
        <translation>Yorum</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="20"/>
        <source>Distance</source>
        <translation>Mesafe</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="23"/>
        <source>Total time</source>
        <translation>Toplam süre</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="25"/>
        <source>Moving time</source>
        <translation>Hareket süresi</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="27"/>
        <source>Date</source>
        <translation>Tarih</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="38"/>
        <source>Links</source>
        <translation>Bağlantılar</translation>
    </message>
</context>
<context>
    <name>WaypointItem</name>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="25"/>
        <source>Name</source>
        <translation>Adı</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="26"/>
        <source>Coordinates</source>
        <translation>Koordinatlar</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="33"/>
        <source>Elevation</source>
        <translation>Rakım</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="36"/>
        <source>Date</source>
        <translation>Tarih</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="40"/>
        <source>Description</source>
        <translation>Açıklama</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="44"/>
        <source>Comment</source>
        <translation>Yorum</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="47"/>
        <source>Symbol</source>
        <translation>Sembol</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="52"/>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="55"/>
        <source>Phone</source>
        <translation>Telefon</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="65"/>
        <source>Links</source>
        <translation>Bağlantılar</translation>
    </message>
</context>
</TS>
